--==========================================================
-- Design units : AssocMemCtrl
--                (entitiy, architecture and configuration)
--
-- File name    : AssocMemCtrl.vhd
--
-- Purpose      : Control Circuit for Associative Memory 
--
-- Limitations  : 
--
-- Library      : WORK
--
-- Dependencies :
--
-- Author       : Hans-Peter Eich, REFT
--
-- Simulator    : Synopsys V3.1a on SUN SPARCstation 10
--
-------------------------------------------------------------
-- Revision list
-- Version Author Date           Changes
--
-- V1.0    hpe    02.04.95       new
-- V2.0    cjt    18.10.95       ESA-Standard, reset on active low
--===========================================================

LIBRARY IEEE;
USE IEEE.std_logic_1164.all;
USE work.ELEMpack.all;
USE work.AssocMemPack.all;

ENTITY AssocMemCtrl IS
  PORT (Store        : IN std_logic;
        SelectAdrMat : IN std_logic;
        WriteEnable  : IN std_logic;
        Reset        : IN std_logic; -- reset on active low
        StoreRes     : OUT std_logic);
END AssocMemCtrl;

--==========================ARCHITECTURE=====================

ARCHITECTURE Structure OF AssocMemCtrl IS
  SIGNAL notReset,notWriteEnable,notStore,Set: std_logic := '0';
BEGIN

  Inv0 : INV
    PORT MAP (Reset,
              notReset);

  Inv1 : INV
    PORT MAP (WriteEnable,
              notWriteEnable);

  Inv2 : INV
    PORT MAP (Store,
              notStore);

  Flag : RSFF
    PORT MAP (Set,
              notReset,
              StoreRes,
              open);

  Constraint : AND4
    PORT MAP (notStore,
              SelectAdrMat,             
              notWriteEnable,
              Reset,
              Set);

END Structure;

--==========================CONFIGURATION====================
CONFIGURATION AssocMemCtrl_Config OF AssocMemCtrl IS

FOR Structure

  FOR Inv0 : INV
    USE ENTITY work.inv(Behavior);
  END FOR;

  FOR Inv1 : INV
    USE ENTITY work.inv(Behavior);
  END FOR;

  FOR Inv2 : INV
    USE ENTITY work.inv(Behavior);
  END FOR;

  FOR Flag : RSFF
    USE ENTITY work.rsff(Behavior);
  END FOR;

  FOR Constraint : AND4
    USE ENTITY work.and4(Behavior);
  END FOR;

END FOR; -- Structure

END AssocMemCtrl_Config;


