--==========================================================
-- Design units : StopWatchCount (Entity,Architecture,Configuration)
--
-- File name    : StopWatchCount.vhd
--
-- Purpose      : Copunting device for StopWatch
--
-- Limitations  : none
--
-- Library      : IEEE
--
-- Dependencies : StopWatchPack,Mod_6_Count,Mod_10_Count
--
-- Author       : Claus-Juergen Thomas, REFT
--
-- Simulator    : Synopsys V3.1a on SUN SPARCstation 10
--
-----------------------------------------------------------
-- Revision list
-- Version Author Date           Changes
--
--  v 1.0  cjt    18.01.96       new
--=========================================================

LIBRARY IEEE;
USE IEEE.std_logic_1164.all;
USE work.ELEMpack.all;
USE work.Stoppack.all;

ENTITY StopWatchCount IS
PORT(StartStop  : IN  std_logic;
     Reset      : IN  std_logic;
     Clk        : IN  std_logic;
     Tenths_out : OUT std_logic_vector(3 Downto 0);
     Seconds_out: OUT std_logic_vector(3 Downto 0);
     Tens_out   : OUT std_logic_vector(2 Downto 0));
END StopWatchCount;

--============================ARCHITECTURE==================

ARCHITECTURE Structure OF StopWatchCount IS

SIGNAL i_out_tenths,i_out_seconds,i_out_tens:std_logic;
SIGNAL not_i_o_tenths,not_i_o_seconds: std_logic;

BEGIN

Count_tenths: Mod_10_Counter
PORT MAP(StartStop,
         Reset,
         Clk,
         Tenths_out,
         i_out_tenths);

Count_seconds: Mod_10_Counter
PORT MAP(i_out_tenths,
         Reset,
         i_out_tenths,
         Seconds_out,
         i_out_seconds);

Count_tens: Mod_6_Counter
PORT MAP(i_out_seconds,
         Reset,
         i_out_seconds,
         tens_out,
         i_out_tens);

END Structure;

--============================CONFIGURATION=================

CONFIGURATION StopWatchCount_config OF StopWatchCount IS
  FOR Structure
    FOR ALL : Mod_10_Counter
      USE ENTITY work.mod_10_counter(Structure);
    END FOR;
    FOR Count_tens: Mod_6_Counter
      USE ENTITY work.mod_6_counter(Structure);
    END FOR;
  END FOR;
END StopWatchCount_config;
